package com.ruoyi.oa.mapper;

import java.util.List;
import com.ruoyi.oa.domain.CmcManageDept;

/**
 * cmc领导分管Mapper接口
 * 
 * @author cmc
 * @date 2024-07-04
 */
public interface CmcManageDeptMapper 
{
    /**
     * 查询cmc领导分管
     * 
     * @param userId cmc领导分管主键
     * @return cmc领导分管
     */
    public CmcManageDept selectCmcManageDeptByUserId(Long userId);

    /**
     * 查询cmc领导分管列表
     * 
     * @param cmcManageDept cmc领导分管
     * @return cmc领导分管集合
     */
    public List<CmcManageDept> selectCmcManageDeptList(CmcManageDept cmcManageDept);

    /**
     * 新增cmc领导分管
     * 
     * @param cmcManageDept cmc领导分管
     * @return 结果
     */
    public int insertCmcManageDept(CmcManageDept cmcManageDept);

    /**
     * 修改cmc领导分管
     * 
     * @param cmcManageDept cmc领导分管
     * @return 结果
     */
    public int updateCmcManageDept(CmcManageDept cmcManageDept);

    /**
     * 删除cmc领导分管
     * 
     * @param userId cmc领导分管主键
     * @return 结果
     */
    public int deleteCmcManageDeptByUserId(Long userId);

    /**
     * 批量删除cmc领导分管
     * 
     * @param userIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteCmcManageDeptByUserIds(Long[] userIds);
}
